@@ -526,7 +526,7 @@ static void convertEffect(mp_ubyte effIn, mp_ubyte opIn, mp_ubyte& effOut, mp_ub
 					}
 					else if (y==0x0F)
 					{
-						workBuffers.globalVolume -= y;
+						workBuffers.globalVolume -= x;
 						if (workBuffers.globalVolume < 0)
 							workBuffers.globalVolume = 0;
 						effOut = 0x10;
@@ -1012,7 +1012,7 @@ static void fillWorkBuffers(const XModule* module, mp_uint32 orderListIndex, TWo
 										}
 										else if (y==0x0F)
 										{
-											workBuffers.globalVolume -= y;
+											workBuffers.globalVolume -= x;
 											if (workBuffers.globalVolume < 0)
 												workBuffers.globalVolume = 0;
 										}
@@ -1838,10 +1838,6 @@ static mp_uword prep(mp_sint32 v)
 
 mp_sint32 XModule::saveProtrackerModule(const SYSCHAR* fileName)
 {
-	static const char* modIDs[16] = {"2CHN","M.K.","6CHN","8CHN","10CH",
-									 "12CH","14CH","16CH","18CH","20CH",
-									 "22CH","24CH","26CH","28CH","30CH","32CH"};
-
 	static const mp_sint32 periods[12] = {1712,1616,1524,1440,1356,1280,1208,1140,1076,1016,960,907};
 
 	static const mp_sint32 originalPeriods[] = {1712,1616,1524,1440,1356,1280,1208,1140,1076,1016,960,906,
@@ -1969,12 +1965,10 @@ unused:
 	f.write(ord, 1, 128);
 	
 	mp_uword numChannels = header.channum&1 ? header.channum+1 : header.channum;	
-	
-	if (numChannels < 2 || numChannels > 32)
+
+	if (numChannels < 1 || numChannels > 99)
 		return MP_UNSUPPORTED;
 	
-	f.write(modIDs[(numChannels >> 1)-1], 1, 4);
-	
 // - patterns -------------------------------------------
 	mp_sint32 numPatterns = 0;
 	for (i = 0; i < 128; i++)
@@ -1982,6 +1976,26 @@ unused:
 		if (ord[i] > numPatterns)
 			numPatterns = ord[i];
 	}
+
+	char modMagic[4];
+	if(numChannels == 4)
+	{
+		// ProTracker may not load files with more than 64 patterns correctly if we do not specify the M!K! magic.
+		if(numPatterns <= 63)
+			memcpy(modMagic, "M.K.", 4);
+		else
+			memcpy(modMagic, "M!K!", 4);
+	} else if(numChannels < 10)
+	{
+		memcpy(modMagic, "0CHN", 4);
+		modMagic[0] += static_cast<char>(numChannels);
+	} else
+	{
+		memcpy(modMagic, "00CH", 4);
+		modMagic[0] += static_cast<char>(numChannels / 10u);
+		modMagic[1] += static_cast<char>(numChannels % 10u);
+	}
+	f.write(modMagic, 1, 4);
 	
 	for (i = 0; i < numPatterns+1; i++)
 	{
@@ -2109,6 +2123,8 @@ unused:
 #ifdef MILKYTRACKER
 bool TXMPattern::saveExtendedPattern(const SYSCHAR* fileName) const
 {
+	// Note: For FT2 compatibility, .XP files are fixed at 32 channels.
+	// TODO:  Create a version 2 format for variable channel counts
 	TWorkBuffers workBuffers;
 
 	// ------ start ---------------------------------
@@ -2120,13 +2136,13 @@ bool TXMPattern::saveExtendedPattern(const SYSCHAR* fileName) const
 	f.writeWord(0x1);
 	f.writeWord(rows);
 	
-	mp_sint32 len = rows * channum * 5;
+	mp_sint32 len = rows * 32 * 5;
 	
 	mp_ubyte* srcPattern = new mp_ubyte[len];
 	
 	memset(srcPattern, 0, len);
 	
-	convertPattern(NULL, this, srcPattern, channum, workBuffers, false);		
+	convertPattern(NULL, this, srcPattern, 32, workBuffers, false);
 	
 	f.write(srcPattern, 1, len);
 	
@@ -2151,14 +2167,12 @@ bool TXMPattern::saveExtendedTrack(const SYSCHAR* fileName, mp_uint32 channel) c
 	f.writeWord(0x1);
 	f.writeWord(rows);
 	
-	mp_sint32 len = rows * channum * 5;
+	mp_sint32 len = rows * 5;
 	
-	mp_ubyte* srcPattern = new mp_ubyte[len];
+	mp_ubyte* srcPattern = new mp_ubyte[rows * channum * 5];
 	mp_ubyte* dstPattern = new mp_ubyte[len];
 	
-	memset(srcPattern, 0, len);
-	
-	convertPattern(NULL, this, srcPattern, channum, workBuffers, false);		
+	convertPattern(NULL, this, srcPattern, channum, workBuffers, false);
 	
 	for (mp_sint32 r = 0; r < rows; r++)
 	{
